@@ -9,22 +9,22 @@ rotorua <- GE2014 %>%
     summarise(Votes = sum(Votes)) %>%
     arrange(desc(Votes))
 
-expect_that(
+expect_equal(
     tolower(as.character(rotorua[1, 1])),
-    equals(tolower("McClay, Todd Michael"))
+    tolower("McClay, Todd Michael")
 )
 
-expect_that(
+expect_equal(
     as.numeric(rotorua[1, 2]),
-    equals(18715)
+    18715
 )
 
-expect_that(
+expect_equal(
     tolower(as.character(rotorua[6, 1])),
-    equals(tolower("russell, lyall"))
+    tolower("russell, lyall")
 )
 
-expect_that(
+expect_equal(
     as.numeric(rotorua[6, 2]),
-    equals(132)
+    132
 )
